==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/organiseur/lang/organiseur_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/organiseur?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_enregistrer_brouillon' => 'Ontwerp op te slaan',
	'bouton_envoyer_message' => 'Opsturen',
	'bouton_envoyer_message_maintenant' => 'Opsturen nu',

	// C
	'cal_jour_entier' => 'Hele dag',
	'cal_par_jour' => 'dag',
	'cal_par_mois' => 'maand',
	'cal_par_semaine' => 'week',

	// E
	'erreur_date' => 'De datum is ongeldig',
	'erreur_date_avant_apres' => 'Geef een einddatum na de begindatum aan !',
	'erreur_date_corrigee' => 'De datum werd verbeterd',
	'erreur_destinataire_invalide' => 'De ontvanger @dest@ is niet geldig',
	'erreur_heure' => 'Tijdstip is ongeldig',
	'erreur_heure_corrigee' => 'Het tijdstip werd verbeterd',

	// I
	'icone_ecrire_nouveau_message' => 'Een nieuwe boodschap opsturen',
	'icone_ecrire_nouveau_pensebete' => 'Een herinneringsnota aanmaken',
	'icone_ecrire_nouvelle_annonce' => 'Een nieuwe aankondiging aanmaken',
	'icone_effacer_message' => 'Deze boodschap uitwissen',
	'icone_modifier_annonce' => 'Deze aankondiging veranderen',
	'icone_modifier_message' => 'Dit bericht aanpassen',
	'icone_modifier_pensebete' => 'De herinneringsnota veranderen',
	'icone_supprimer_message' => 'Deze boodschap uitwissen',
	'info_1_message_envoye' => '1 boodschap opgestuurd',
	'info_1_message_nonlu' => '1 nieuwe boodschap',
	'info_agenda_interne' => 'Interne agenda',
	'info_message_a' => 'Naar',
	'info_message_date' => 'Datum',
	'info_message_date_debut' => 'Begindatum',
	'info_message_date_fin' => 'Einddatum',
	'info_message_de' => 'Van',
	'info_message_non_lu' => 'Nieuwe boodschap',
	'info_message_objet' => 'Onderwerp',
	'info_nb_messages_envoyes' => '@nb@ boodschapppen opgestuurd',
	'info_nb_messages_nonlus' => '@nb@ nieuwe boodschappen',
	'info_selection_annonces' => 'Aankondigingen',
	'info_selection_messages' => 'Boodschappen',
	'info_selection_pensebetes' => 'Herinneringsnotas',
	'info_type_message_affich' => 'Aankondiging',
	'info_type_message_normal' => 'Boodschap',
	'info_type_message_pb' => 'Herinneringsnota',
	'info_type_message_rv' => 'Afspraak',

	// L
	'label_destinataires' => 'Naar',
	'label_texte' => 'Tekst',
	'label_titre' => 'Onderwerp',
	'loading' => 'Aan het laden...',

	// M
	'message' => 'Boodschap',
	'messages' => 'Boodschappen',

	// N
	'notification_annonce_lire_a_ladresse' => 'Je kan ze lezen op het volgende addres: @url@.',
	'notification_annonce_publie_1' => '[@nom_site_spip@] Algemene aankondiging',
	'notification_message_lire_a_ladresse' => 'Je kan de boodschap lezen en beantwoorden op het adres: @url@.',
	'notification_message_publie_1' => '[@nom_site_spip@] Nieuwe boodschap',
	'notification_message_recu_de' => 'Je hebt een nieuwe boodschap gekregen van @nom@.',

	// T
	'texte_message_brouillon' => 'Deze boodschapsontwerp werd opgeslagen.',
	'titre_agenda_rv' => 'Afspraak',
	'titre_boite_envoi' => 'Outbox',
	'titre_boite_reception' => 'INBOX'
);

?>

==> spip_3.2.3.orig.tar.xz: spip/plugins-dist/organiseur/lang/organiseur_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/organiseur?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_enregistrer_brouillon' => 'In klad opslaan',
	'bouton_envoyer_message' => 'Verzenden',
	'bouton_envoyer_message_maintenant' => 'Nu verzenden',

	// C
	'cal_jour_entier' => 'Hele dag',
	'cal_par_jour' => 'dag',
	'cal_par_mois' => 'maand',
	'cal_par_semaine' => 'week',

	// E
	'erreur_date' => 'De datum is ongeldig',
	'erreur_date_avant_apres' => 'Geef een einddatum na de begindatum aan!',
	'erreur_date_corrigee' => 'De datum werd verbeterd',
	'erreur_destinataire_invalide' => 'De ontvanger @dest@ is niet geldig',
	'erreur_heure' => 'Tijdstip is ongeldig',
	'erreur_heure_corrigee' => 'Het tijdstip werd verbeterd',

	// I
	'icone_ecrire_nouveau_message' => 'Een nieuwe bericht opsturen',
	'icone_ecrire_nouveau_pensebete' => 'Een herinneringsmemo aanmaken',
	'icone_ecrire_nouvelle_annonce' => 'Een nieuwe aankondiging aanmaken',
	'icone_effacer_message' => 'Dit bericht wissen',
	'icone_modifier_annonce' => 'Deze aankondiging veranderen',
	'icone_modifier_message' => 'Dit bericht aanpassen',
	'icone_modifier_pensebete' => 'De herinneringsmemo veranderen',
	'icone_supprimer_message' => 'Dit bericht wissen',
	'info_1_message_envoye' => '1 boodschap opgestuurd',
	'info_1_message_nonlu' => '1 nieuwe boodschap',
	'info_agenda_interne' => 'Interne agenda',
	'info_message_a' => 'Naar',
	'info_message_date' => 'Datum',
	'info_message_date_debut' => 'Begindatum',
	'info_message_date_fin' => 'Einddatum',
	'info_message_de' => 'Van',
	'info_message_non_lu' => 'Nieuwe bericht',
	'info_message_objet' => 'Onderwerp',
	'info_nb_messages_envoyes' => '@nb@ boodschapppen opgestuurd',
	'info_nb_messages_nonlus' => '@nb@ nieuwe boodschappen',
	'info_selection_annonces' => 'Aankondigingen',
	'info_selection_messages' => 'Boodschappen',
	'info_selection_pensebetes' => 'Herinneringsmemo’s',
	'info_type_message_affich' => 'Aankondiging',
	'info_type_message_normal' => 'Bericht',
	'info_type_message_pb' => 'Herinneringsmemo',
	'info_type_message_rv' => 'Afspraak',

	// L
	'label_destinataires' => 'Naar',
	'label_texte' => 'Tekst',
	'label_titre' => 'Onderwerp',
	'loading' => 'Aan het laden...',

	// M
	'message' => 'Bericht',
	'messages' => 'Berichten',

	// N
	'notification_annonce_lire_a_ladresse' => 'Je kan ze lezen op het volgende addres: @url@.',
	'notification_annonce_publie_1' => '[@nom_site_spip@] Algemene aankondiging',
	'notification_message_lire_a_ladresse' => 'Je kan het bericht lezen en beantwoorden op het adres: @url@.',
	'notification_message_publie_1' => '[@nom_site_spip@] Nieuw bericht',
	'notification_message_recu_de' => 'Je hebt een nieuwe bericht gekregen van @nom@.',

	// T
	'texte_message_brouillon' => 'Deze bericht werd als klad opgeslagen.',
	'titre_agenda_rv' => 'Afspraak',
	'titre_boite_envoi' => 'Outbox',
	'titre_boite_reception' => 'INBOX'
);
